==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/pages/src/lib/screensaver.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {RSIntKeyboard} from "front-ui";
import {ServerState, ServerAction, WifiState, ConnectionHandler, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-screensaver-component",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-screensaver"></i> <?php _('Screensaver') ?></rs-headline>
        <div class="content-h1 " style="padding: 0;" rsDrag>
          <div>
            <div class="iconlist">
              <div class="button-icon sep-icon">
                <rs-button class="secondary outline full" (hit)="setTime()">
                  <i class="rs rs-screensaver fw"></i>
                  <h3>{{ tScreensaverTimeout }}<br>
                    {{ server?.settings["screensaver"].timeout }} <?php _('minutes') ?></h3></rs-button>
              </div>
            </div>
            <div ng-if="wifi?.screensaver && server" class="margin-leftright">
              <rs-switch [checked]="energySend" (checkedChange)="toggleEnergy($event)"></rs-switch>
              {{ tDisableDisplay }}
            </div>
            <div class="alert info margin-top margin-leftright">
              {{ tScreensaverInfo }}
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})

export class ScreensaverComponent implements OnDestroy {
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  server: ServerState = undefined;
  wifi: WifiState = undefined;

  private serverSubscription: SubscriptionLike;
  private wifiSubscription: SubscriptionLike;
  energySend: boolean = undefined;
  tScreensaverTimeout = "<?php _('Screensaver Timeout') ?>";
  tScreensaverInfo = "<?php _('If your screen goes black after some time, set timout to that time to protect for unintentionally activating functions. If not, use it to dim screen or set to 0 to disable it.') ?>";
  tDisableDisplay = "<?php _('Disable Display') ?>";

  constructor(private intKbd: RSIntKeyboard,
              private serverAction: ServerAction,
              private con: ConnectionHandler,
              private store: Store<RepetierState>) {
    this.server$ = store.select("server");
    this.wifi$ = store.select("wifi");
    this.serverSubscription = this.server$.subscribe((p: ServerState) => {
      if (p.settings && p.settings["screensaver"]) {
        this.server = p;
        if (this.energySend === undefined) {
          this.energySend = p.settings["screensaver"].energySaving;
        }
      }
    });
    this.wifiSubscription = this.wifi$.subscribe((p: WifiState) => {
      this.wifi = p;
    });
  }

  ngOnDestroy(): void {
    this.serverSubscription.unsubscribe();
    this.wifiSubscription.unsubscribe();
  }

  toggleEnergy(newVal): void {
    if (this.energySend === undefined || this.server === undefined || !this.server.settings["screensaver"]) {
      return;
    } // break loop
    this.energySend = newVal;
    this.serverAction.updateSetting("screensaver", Object.assign({}, this.server.settings["screensaver"], {energySaving: newVal}));
    if (this.server.settings["screensaver"].timeout === 0 || !newVal) {
      this.con.send("screensaver", {enable: 0, timeout: 0});
    } else {
      this.con.send("screensaver", {enable: 1, timeout: this.server.settings["screensaver"].timeout * 60 + 10});
    }
  }

  setTime(): void {
    this.intKbd.getInt(this.server.settings["screensaver"].timeout, "<i class=\"rs rs-screensaver\"></i> " + "<?php _('Screensaver') ?>", {
      min: 0,
      max: 240,
      unit: "<?php _('minutes') ?>",
      presets: [0, 5, 10, 15]
    }).then(
      (v) => {
        this.serverAction.updateSetting("screensaver", Object.assign({}, this.server.settings["screensaver"], {timeout: v}));
        if (v > 0 && this.energySend) {
          this.con.send("screensaver", {enable: 1, timeout: v * 60 + 10});
        } // modify
        if (v === 0) {
          this.con.send("screensaver", {enable: 0, timeout: 0});
        }
      }, () => {
      }
    );
  }
}

==> RSTouchscreenNG-1.4.17.zip: RSTouchscreenNG/projects/pages/src/lib/screensaver.component.ts <==
/* (C) 2016-2024 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {RSIntKeyboard} from "front-ui";
import {ServerState, ServerAction, WifiState, ConnectionHandler, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-screensaver-component",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-screensaver"></i> <?php _('Screensaver') ?></rs-headline>
        <div class="content-h1 " style="padding: 0;" rsDrag *ngIf="(server$|async).features['touch-screensaver']">
          <div>
            <div class="iconlist">
              <div class="button-icon sep-icon">
                <rs-button class="secondary outline full" (hit)="setTime()">
                  <i class="rs rs-screensaver fw"></i>
                  <h3>{{ tScreensaverTimeout }}<br>
                    {{ server?.settings["screensaver"].timeout }} <?php _('minutes') ?></h3></rs-button>
              </div>
            </div>
            <div ng-if="wifi?.screensaver && server" class="margin-leftright">
              <rs-switch [checked]="energySend" (checkedChange)="toggleEnergy($event)"></rs-switch>
              {{ tDisableDisplay }}
            </div>
            <div class="alert info margin-top margin-leftright">
              {{ tScreensaverInfo }}
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})

export class ScreensaverComponent implements OnDestroy {
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  server: ServerState = undefined;
  wifi: WifiState = undefined;

  private serverSubscription: SubscriptionLike;
  private wifiSubscription: SubscriptionLike;
  energySend: boolean = undefined;
  tScreensaverTimeout = "<?php _('Screensaver Timeout') ?>";
  tScreensaverInfo = "<?php _('If your screen goes black after some time, set timout to that time to protect for unintentionally activating functions. If not, use it to dim screen or set to 0 to disable it.') ?>";
  tDisableDisplay = "<?php _('Disable Display') ?>";

  constructor(private intKbd: RSIntKeyboard,
              private serverAction: ServerAction,
              private con: ConnectionHandler,
              private store: Store<RepetierState>) {
    this.server$ = store.select("server");
    this.wifi$ = store.select("wifi");
    this.serverSubscription = this.server$.subscribe((p: ServerState) => {
      if (p.settings && p.settings["screensaver"]) {
        this.server = p;
        if (this.energySend === undefined) {
          this.energySend = p.settings["screensaver"].energySaving;
        }
      }
    });
    this.wifiSubscription = this.wifi$.subscribe((p: WifiState) => {
      this.wifi = p;
    });
  }

  ngOnDestroy(): void {
    this.serverSubscription.unsubscribe();
    this.wifiSubscription.unsubscribe();
  }

  toggleEnergy(newVal): void {
    if (this.energySend === undefined || this.server === undefined || !this.server.settings["screensaver"]) {
      return;
    } // break loop
    this.energySend = newVal;
    this.serverAction.updateSetting("screensaver", Object.assign({}, this.server.settings["screensaver"], {energySaving: newVal}));
    if (this.server.settings["screensaver"].timeout === 0 || !newVal) {
      this.con.send("screensaver", {enable: 0, timeout: 0});
    } else {
      this.con.send("screensaver", {enable: 1, timeout: this.server.settings["screensaver"].timeout * 60 + 10});
    }
  }

  setTime(): void {
    this.intKbd.getInt(this.server.settings["screensaver"].timeout, "<i class=\"rs rs-screensaver\"></i> " + "<?php _('Screensaver') ?>", {
      min: 0,
      max: 240,
      unit: "<?php _('minutes') ?>",
      presets: [0, 5, 10, 15]
    }).then(
      (v) => {
        this.serverAction.updateSetting("screensaver", Object.assign({}, this.server.settings["screensaver"], {timeout: v}));
        if (v > 0 && this.energySend) {
          this.con.send("screensaver", {enable: 1, timeout: v * 60 + 10});
        } // modify
        if (v === 0) {
          this.con.send("screensaver", {enable: 0, timeout: 0});
        }
      }, () => {
      }
    );
  }
}
